@@ -1,4 +1,8 @@
 package Dist::Zilla::PluginBundle::Milla;
+
+use strict;
+use version; our $VERSION = version->declare('v1.0.16');
+
 use Dist::Milla;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy',
@@ -78,7 +82,7 @@ sub configure {
         [ 'PodSyntaxTests' ],
         [ 'MetaYAML' ],
         [ 'License' ],
-        [ 'ReadmeFromPod', { readme => 'README' } ],
+        [ 'ReadmeAnyFromPod', 'ReadmeAnyFromPod/ReadmeTextInBuild' ],
         [ 'ExtraTests' ],
         [ 'ExecDir', { dir => 'script' } ],
         [ 'ShareDir' ],
